darkhistory.physics.photo_ion_xsec — DarkHistory documentation

# darkhistory.physics.photo_ion_xsec

`darkhistory.physics.` `photo_ion_xsec`(eng, species)

  Photoionization cross section in cm2.

  Cross sections for hydrogen, neutral helium and singly-ionized helium are available.

  Parameters: | eng : ndarray Energy to evaluate the cross section at. species : {‘HI’, ‘HeI’, ‘HeII’} Species of interest.
  Returns: | xsec : ndarray Photoionization cross section.

#### Previous topic

darkhistory.physics.photo_ion_rate

#### Next topic

darkhistory.physics.coll_exc_xsec

### This Page

Show Source